@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from operator import attrgetter
+from pathlib import Path
 from typing import TYPE_CHECKING, TypeVar
 
 import asyncstdlib
@@ -9,6 +11,13 @@ from discord.ext import commands
 from pylav import getLogger
 from pylav.types import ContextT, InteractionT
 
+try:
+    from redbot.core.i18n import Translator
+
+    _ = Translator("PyLavPlayer", Path(__file__))
+except ImportError:
+    _ = lambda x: x
+
 LOGGER = getLogger("red.3pt.PyLav-Shared.converters.radio")
 
 if TYPE_CHECKING:
@@ -32,10 +41,10 @@ else:
             try:
                 stations = await ctx.lavalink.radio_browser.stations()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"Station with name `{arg}` not found.") from e
+                raise commands.BadArgument(_("Station with name `{arg}` not found.").format(arg=arg)) from e
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), stations)):
-                return r
-            raise commands.BadArgument(f"Station with name `{arg}` not found.")
+                return await asyncstdlib.sorted(r, key=attrgetter("lastcheckoktime_iso8601"), reverse=True)
+            raise commands.BadArgument(_("Station with name `{arg}` not found.").format(arg=arg))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[Station]:
@@ -48,7 +57,7 @@ else:
         async def autocomplete(cls, interaction: InteractionT, current: str) -> list[Choice]:
             data = interaction.data
             options = data.get("options", [])
-            kwargs = {"order": "clickcount"}
+            kwargs = {"order": "lastcheckok"}
             if options:
                 country_code = [v for v in options if v.get("name") == "countrycode"]
                 country = [v for v in options if v.get("name") == "country"]
@@ -87,13 +96,13 @@ else:
                             True for t in await interaction.client.lavalink.radio_browser.tags() if t.name == val
                         )
                     elif len(tags) > 1:
-                        kwargs["tag_list"] = [tv for t in tags if (tv := t.get("value"))]
+                        kwargs["tag_list"] = ",".join([tv for t in tags if (tv := t.get("value"))])
 
             if current:
                 kwargs["name"] = current
             stations = await interaction.client.lavalink.radio_browser.search(limit=25, **kwargs)
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in stations
                 if current.lower() in n.name.lower()
             ][:25]
@@ -107,10 +116,10 @@ else:
             try:
                 tags = await ctx.lavalink.radio_browser.tags()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"Tag with name `{arg}` not found.") from e
+                raise commands.BadArgument(_("Tag with name `{arg}` not found.").format(arg=arg)) from e
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), tags)):
                 return r
-            raise commands.BadArgument(f"Tag with name `{arg}` not found.")
+            raise commands.BadArgument(_("Tag with name `{arg}` not found.").format(arg=arg))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[Tag]:
@@ -123,7 +132,7 @@ else:
         async def autocomplete(cls, interaction: InteractionT, current: str) -> list[Choice]:
             tags = await interaction.client.lavalink.radio_browser.tags()
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in tags
                 if current.lower() in n.name.lower()
             ][:25]
@@ -137,10 +146,10 @@ else:
             try:
                 langs = await ctx.lavalink.radio_browser.languages()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"Language with name `{arg}` not found.") from e
+                raise commands.BadArgument(_("Language with name `{arg}` not found.").format(arg=arg)) from e
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), langs)):
                 return r
-            raise commands.BadArgument(f"Language with name `{arg}` not found.")
+            raise commands.BadArgument(_("Language with name `{arg}` not found.)").format(arg=arg))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[Language]:
@@ -154,7 +163,7 @@ else:
             languages = await interaction.client.lavalink.radio_browser.languages()
 
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in languages
                 if current.lower() in n.name.lower()
             ][:25]
@@ -168,10 +177,10 @@ else:
             try:
                 states = await ctx.lavalink.radio_browser.states()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"State with name `{arg}` not found.") from e
+                raise commands.BadArgument(_("State with name `{arg}` not found.")) from e
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), states)):
                 return r
-            raise commands.BadArgument(f"State with name `{arg}` not found.")
+            raise commands.BadArgument(_("State with name `{arg}` not found."))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[State]:
@@ -190,11 +199,9 @@ else:
 
                 if country and (val := country[0].get("value")):
                     kwargs["country"] = val
-            LOGGER.debug(f"StateConverter Autocompleting {current} with {kwargs} and {options}")
-
             states = await interaction.client.lavalink.radio_browser.states(**kwargs)
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in states
                 if current.lower() in n.name.lower()
             ][:25]
@@ -208,10 +215,10 @@ else:
             try:
                 codecs = await ctx.lavalink.radio_browser.codecs()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"Codec with name `{arg}` not found.") from e
+                raise commands.BadArgument(_("Codec with name `{arg}` not found.").format(arg=arg)) from e
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), codecs)):
                 return r
-            raise commands.BadArgument(f"Codec with name `{arg}` not found.")
+            raise commands.BadArgument(_("Codec with name `{arg}` not found.").format(arg=arg))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[Codec]:
@@ -224,7 +231,7 @@ else:
         async def autocomplete(cls, interaction: InteractionT, current: str) -> list[Choice]:
             codecs = await interaction.client.lavalink.radio_browser.codecs()
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in codecs
                 if current.lower() in n.name.lower()
             ][:25]
@@ -238,11 +245,11 @@ else:
             try:
                 countrycodes = await ctx.lavalink.radio_browser.countrycodes()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"Country code `{arg}` not found.") from e
+                raise commands.BadArgument(_("Country code `{arg}` not found.").format(arg=arg)) from e
 
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), countrycodes)):
                 return r
-            raise commands.BadArgument(f"Country code `{arg}` not found.")
+            raise commands.BadArgument(_("Country code `{arg}` not found.").format(arg=arg))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[CountryCode]:
@@ -255,7 +262,7 @@ else:
         async def autocomplete(cls, interaction: InteractionT, current: str) -> list[Choice]:
             countrycodes = await interaction.client.lavalink.radio_browser.countrycodes()
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in countrycodes
                 if current.lower() in n.name.lower()
             ][:25]
@@ -269,10 +276,10 @@ else:
             try:
                 countries = await ctx.lavalink.radio_browser.countries()
             except EntryNotFoundError as e:
-                raise commands.BadArgument(f"Country with name `{arg}` not found.") from e
+                raise commands.BadArgument(_("Country with name `{arg}` not found.").format(arg=arg)) from e
             if r := await asyncstdlib.list(asyncstdlib.filter(lambda n: arg.lower() in n.name.lower(), countries)):
                 return r
-            raise commands.BadArgument(f"Country with name `{arg}` not found.")
+            raise commands.BadArgument(_("Country with name `{arg}` not found.").format(arg=arg))
 
         @classmethod
         async def transform(cls, interaction: InteractionT, argument: str) -> list[Country]:
@@ -292,7 +299,7 @@ else:
                     kwargs["code"] = val
             countries = await interaction.client.lavalink.radio_browser.countries(**kwargs)
             return [
-                Choice(name=n.name[:99] if n.name else "Unnamed", value=f"{n.name}")
+                Choice(name=n.name[:95] if n.name else _("Unnamed"), value=f"{n.name}")
                 for n in countries
                 if current.lower() in n.name.lower()
             ][:25]
