@@ -22,8 +22,13 @@ if not ENV_FILE.exists():
     POSTGRES_PASSWORD = os.getenv("PYLAV__POSTGRES_PASSWORD", os.getenv("PGPASSWORD"))
     POSTGRES_USER = os.getenv("PYLAV__POSTGRES_USER", os.getenv("PGUSER"))
     POSTGRES_DATABASE = os.getenv("PYLAV__POSTGRES_DB", os.getenv("PGDATABASE"))
-    POSTGRES_HOST = os.getenv("PYLAV__POSTGRES_HOST", os.getenv("PGHOST"))
-
+    _POSTGRES_HOST = os.getenv("PYLAV__POSTGRES_HOST", os.getenv("PGHOST"))
+    POSTGRES_SOCKET = os.getenv("PYLAV__POSTGRES_SOCKET")
+    if POSTGRES_SOCKET is not None:
+        POSTGRES_PORT = None
+        POSTGRES_HOST = POSTGRES_SOCKET
+    else:
+        POSTGRES_HOST = _POSTGRES_HOST
     JAVA_EXECUTABLE = os.getenv("PYLAV__JAVA_EXECUTABLE", "java")
     LINKED_BOT_IDS = list(map(str.strip, os.getenv("PYLAV__LINKED_BOT_IDS", "").split("|")))
     USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE = bool(int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE", "0")))
@@ -51,7 +56,8 @@ if not ENV_FILE.exists():
         "PYLAV__POSTGRES_PASSWORD": POSTGRES_PASSWORD,
         "PYLAV__POSTGRES_USER": POSTGRES_USER,
         "PYLAV__POSTGRES_DB": POSTGRES_DATABASE,
-        "PYLAV__POSTGRES_HOST": POSTGRES_HOST,
+        "PYLAV__POSTGRES_SOCKET": POSTGRES_SOCKET,
+        "PYLAV__POSTGRES_HOST": _POSTGRES_HOST,
         "PYLAV__REDIS_FULLADDRESS_RESPONSE_CACHE": REDIS_FULL_ADDRESS_RESPONSE_CACHE,
         "PYLAV__JAVA_EXECUTABLE": JAVA_EXECUTABLE,
         "PYLAV__LINKED_BOT_IDS": LINKED_BOT_IDS,
@@ -94,6 +100,14 @@ else:
             POSTGRES_HOST = os.getenv("PYLAV__POSTGRES_HOST", os.getenv("PGHOST"))
             data_new["PYLAV__POSTGRES_HOST"] = POSTGRES_HOST
 
+        if (POSTGRES_SOCKET := data.get("PYLAV__POSTGRES_SOCKET")) is None:
+            POSTGRES_SOCKET = os.getenv("PYLAV__POSTGRES_SOCKET")
+            data_new["PYLAV__POSTGRES_SOCKET"] = POSTGRES_SOCKET
+
+        if POSTGRES_SOCKET is not None:
+            POSTGRES_PORT = None
+            POSTGRES_HOST = POSTGRES_SOCKET
+
         if (REDIS_FULL_ADDRESS_RESPONSE_CACHE := data.get("PYLAV__REDIS_FULL_ADDRESS_RESPONSE_CACHE")) is None:
             REDIS_FULL_ADDRESS_RESPONSE_CACHE = os.getenv("PYLAV__REDIS_FULL_ADDRESS_RESPONSE_CACHE")
             data_new["PYLAV__REDIS_FULL_ADDRESS_RESPONSE_CACHE"] = REDIS_FULL_ADDRESS_RESPONSE_CACHE
