@@ -482,10 +482,9 @@ class NodeManager:
             use_bundled_pylav_external=USE_BUNDLED_EXTERNAL_PYLAV_NODE,
             use_bundled_lava_link_external=USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE,
         )
-        if config_data.java_path != JAVA_EXECUTABLE:
-            if JAVA_EXECUTABLE != "java" and os.path.exists(JAVA_EXECUTABLE):
-                config_data.java_path = JAVA_EXECUTABLE
-                await config_data.save()
+        if config_data.java_path != JAVA_EXECUTABLE and JAVA_EXECUTABLE != "java" and os.path.exists(JAVA_EXECUTABLE):
+            config_data.java_path = JAVA_EXECUTABLE
+            await config_data.save()
         if config_data.use_bundled_pylav_external:
             if await asyncstdlib.all(True for n in nodes_list if n.host != "ll-gb.draper.wtf"):
                 base_settings = PYLAV_BUNDLED_NODES_SETTINGS["ll-gb.draper.wtf"]
@@ -522,13 +521,6 @@ class NodeManager:
                     PYLAV_BUNDLED_NODES_SETTINGS["lava.link"]["name"],
                 )
         tasks = [asyncio.create_task(n.wait_until_ready()) for n in nodes_list]
-        if (
-            not (
-                self.client._node_manager._unmanaged_external_password
-                and self.client._node_manager._unmanaged_external_host
-            )
-        ) and self.client.enable_managed_node:
-            tasks.append(asyncio.create_task(self.client._local_node_manager.wait_until_connected()))
         if not tasks:
             LOGGER.warning("No nodes found, please add some nodes.")
             return
